@@ -9,28 +9,28 @@ DefaultColorSequence <-  function(){
 #Author ALU  2014, edited MT 2017
 
 DefaultColorSeq <- c(
-					 'magenta','yellow','black','red','green', 'blue','cyan',
+					 'green','blue','magenta','cyan','black','yellow','red',
                      # jetzt kommen einfach alle R farben in random sequenz
-                     'burlywood4',
+                     'orange1',
+					 'rosybrown1',
+					 'floralwhite',
+					 'plum', 
+					 'burlywood4',
                      'gray28',
                      'darksalmon',
                      'orchid2',
                      'plum4',
                      'gray41',
-                     'plum',
-                     'pink1',
                      'coral1',
                      'gray39',
                      'gray',
                      'gray67',
                      'slategray1',
                      'peachpuff1',
-                     'floralwhite',
                      'hotpink',
                      'gray12',
                      'gray88',
-                     'orange1',
-                     'rosybrown1',
+					 'pink1',
                      'royalblue',
                      'gray78',
                      'mediumturquoise',
